==> namazu-2.0.16.tar.gz: namazu-2.0.16/template/NMZ.body.pl <==
<h2><a name="query" id="query">Zapytania</a></h2>

<h3><a name="query-term" id="query-term">Zapytanie pojedycze</a></h3>
<p>
To zapytanie wyszczeglnia tylko jedno okrelenie dla wyszukiwania wszystkich
dokumentw, ktre zawieraj to okrelenie, np.:
</p>

<p class="example">
namazu
</p>

<h3><a name="query-and" id="query-and">Zapytanie typu AND(logiczne i)</a></h3>

<p>
To zapytanie wyszczeglnia 2 lub wicej okrele dla wyszukiwania wszystkich
dokumentw, ktre zawieraj wszystkie podane okrelenia. Moesz wpisa operator
<code class="operator">and</code> pomidzy dwoma lub wicej okreleniami, np.:
</p>

<p class="example">
Linux and Netscape
</p>

<p>
Moesz pomin operator
<code class="operator">and</code> .
Okrelenia, ktre s oddzielone jedn lub wicej spacj s uwaane za zapytanie typu AND.
</p>

<h3><a name="query-or" id="query-or">Zapytanie typu OR(logiczne lub)</a></h3>
<p>
To zapytanie wyszczeglnia 2 lub wicej okrele dla wyszukiwania wszystkich
dokumentw, ktre zawieraj jakiekolwiek z podanych okrele. Moesz wpisa operator
<code class="operator">or</code> pomidzy dwoma lub wicej okreleniami, np.:
</p>

<p class="example">
Linux or FreeBSD
</p>

<h3><a name="query-not" id="query-not">Zapytanie typu NOT(przeczenie)</a></h3>
<p>
To zapytanie wyszczeglnia 2 lub wicej okrele dla wyszukiwania wszystkich
dokumentw, ktre zawieraj pierwsze okrelenie, ale nie zawieraj
nastpnych okrele. Moesz wpisa operator <code class="operator">not</code>
 pomidzy dwoma lub wicej okreleniami, np.:
</p>

<p class="example">
Linux not UNIX
</p>


<h3><a name="query-grouping" id="query-grouping">Grupowanie</a></h3>
<p>
Moesz grupowa zapytania przez zawarcie ich
w nawiasach okragych. Nawiasy powinny by oddzielone przez jedn lub
wicej spacji, np.:
</p>

<p class="example">
( Linux or FreeBSD ) and Netscape not Windows
</p>

<h3><a name="query-phrase" id="query-phrase">Wyszukiwanie fraz</a></h3>
<p>
Moesz szuka wyraenia, ktre skada si z dwch lub wicej okrele
otaczajc je podwjnym cudzysowem jak
<code class="operator">"..."</code> lub klamrami jak <code class="operator">{...}</code>.
Precyzja Namazu  w wyszukiwaniu fraz nie jest 100%,
lecz bdne wyniki trafiaj si bardzo rzadko, np.:
</p>

<p class="example">
{GNU Emacs}
</p>

<!-- foo
<p>
You must choose the latter with Tkanamzu or namazu.el.
Musisz wybra ten ostatni z  Tkanamzu lub namazu.el. ???
</p>
-->

<h3><a name="query-substring" id="query-substring">Wyszukiwanie okrojonych sw</a></h3>
<p>
S trzy typy wyszukiwania okrojonych sw.
</p>

<dl>
<dt>Przedrostkowe dopasowanie</dt>
<dd><code class="example">inter*</code> (okrelenia rozpoczynajce si na <code>inter</code>)</dd>
<dt>Wewntrzne dopasowanie</dt>
<dd><code class="example">*text*</code> (okrelenia zawierajce si wewntrz <code>text</code>)</dd>
<dt>Przyrostkowe dopasowanie</dt>
<dd><code class="example">*net</code> (okrelenia koczce si na <code>net</code>)</dd>
</dl>


<h3><a name="query-regex" id="query-regex">Wyraenia regularne (man grep)</a></h3>

<p>
Moesz uywa wyrae regularnych jako wzr do dopasowywania.
Wyraenia regularne musz by otoczone przez ukoniki tak, jak
<code
class="operator">/.../</code>. Namazu wykorzystuje silnik wyrae regularnych
<ahref="http://www.ruby-lang.org/">Ruby</a>. Oglnie jest on kompatybilny z <a
href="http://www.perl.com/">Perl</a> ,
np.:
</p>

<p class="example">
/pro(gram|blem)s?/
</p>


<h3><a name="query-field" id="query-field">Wyszukiwanie po wyspecyfikowanych polach</a></h3>
<p>
Moesz ograniczy przeszukiwanie do okrelonych pl jak
<code>Subject:</code>, <code>From:</code>,
<code>Message-Id:</code>. Jest to zwaszcza dogodne dla dokumentw typu
Mail/News, np.:
</p>

<ul>
<li><code class="example">+subject:Linux</code><br>
(Zwraca wszystkie dokument zawierajce pola <code>Linux</code>
w <code>Subject:</code> )
</li>

<li><code class="example">+subject:"GNU Emacs"</code><br>
(Zwraca wszystkie dokumenty zawierajce pola <code>GNU Emacs</code>
w <code>Subject:</code> )
</li>

<li><code class="example">+from:foo@bar.jp</code><br>
(Zwraca wszystkie dokument zawierajce pola <code>foo@bar.jp</code>
w <code>From:</code> )
</li>


<li><code class="example">+message-id:&lt;199801240555.OAA18737@foo.bar.jp&gt;</code><br>
(Zwraca pewien dokument zawierajcy wyszczeglnione
<code>Message-Id:</code>)
</li>
</ul>

<h3><a name="query-notes" id="query-notes">Uwagi</a></h3>

<ul>
<li>We wszystkich zapytaniach, Namazu ignoruje wielko znakw alfabetu.
</li>

<li>Japanese phrases are forced to be segmented into
morphemes automatically and are handled them as <a
href="#query-phrase">phrase searching</a>. This processing
causes invalid segmentation occasionally.
<br>Po cholere to tumaczyli na angielski? Ja. w kadym bd razie nie bd, bo nie zamierzam posugiwa
si jz. japoskim.
</li>

<li>Alphabet, numbers or a part of symbols (duplicated in
ASCII) characters which defined in JIS X 0208 (Japanese
Industrial Standards) are handled as ASCII characters.
<br>Ju mam skone oczy wedug normy przemysowej JIS X 0208.
</li>

<li>Namazu radzi sobie z okreleniami zawierajcymi znaki takie jak
<code>TCP/IP</code>, ale to radzenie sobie nie jest kompletne
moesz opisa
<code>TCP and IP</code> zamiast
<code>TCP/IP</code>, ale moe to by powodem zbyt wielu dopasowa (szumu informacyjnego)
</li>

<li>Dopasowania okrojonych sw i szukania po wybranych polach zabieraj
wicej czasu, ni inne metody.
</li>

<li>Jeeli chcesz uywa <code class="operator">and</code>,
<code class="operator">or</code> lub <code
class="operator">not</code> po prostu jako okrele, moesz
otoczy je odpowiednio podwjnym cudzysowem tak, jak
<code
class="operator">"..."</code> lub klamrami tak, jak <code
class="operator">{...}</code>.

<!-- foo
You must choose the latter with Tkanamzu or namazu.el.
???????????????????????????????????? ho ku jank siu?
ja nie znaju sztoo eto.
-->
</li>

</ul>

==> namazu2_2.0.14.orig.tar.gz: namazu-2.0.14/template/NMZ.body.pl <==
<h2><a name="query">Zapytania</a></h2>

<h3><a name="query-term">Zapytanie pojedycze</a></h3>
<p>
To zapytanie wyszczeglnia tylko jedno okrelenie dla wyszukiwania wszystkich
dokumentw, ktre zawieraj to okrelenie, np.:
</p>

<p class="example">
namazu
</p>

<h3><a name="query-and">Zapytanie typu AND(logiczne i)</a></h3>

<p>
To zapytanie wyszczeglnia 2 lub wicej okrele dla wyszukiwania wszystkich
dokumentw, ktre zawieraj wszystkie podane okrelenia. Moesz wpisa operator
<code class="operator">and</code> pomidzy dwoma lub wicej okreleniami, np.:
</p>

<p class="example">
Linux and Netscape
</p>

<p>
Moesz pomin operator
<code class="operator">and</code> .
Okrelenia, ktre s oddzielone jedn lub wicej spacj s uwaane za zapytanie typu AND.
</p>

<h3><a name="query-or">Zapytanie typu OR(logiczne lub)</a></h3>
<p>
To zapytanie wyszczeglnia 2 lub wicej okrele dla wyszukiwania wszystkich
dokumentw, ktre zawieraj jakiekolwiek z podanych okrele. Moesz wpisa operator
<code class="operator">or</code> pomidzy dwoma lub wicej okreleniami, np.:
</p>

<p class="example">
Linux or FreeBSD
</p>

<h3><a name="query-not">Zapytanie typu NOT(przeczenie)</a></h3>
<p>
To zapytanie wyszczeglnia 2 lub wicej okrele dla wyszukiwania wszystkich
dokumentw, ktre zawieraj pierwsze okrelenie, ale nie zawieraj
nastpnych okrele. Moesz wpisa operator <code class="operator">not</code>
 pomidzy dwoma lub wicej okreleniami, np.:
</p>

<p class="example">
Linux not UNIX
</p>


<h3><a name="query-grouping">Grupowanie</a></h3>
<p>
Moesz grupowa zapytania przez zawarcie ich
w nawiasach okragych. Nawiasy powinny by oddzielone przez jedn lub
wicej spacji, np.:
</p>

<p class="example">
( Linux or FreeBSD ) and Netscape not Windows
</p>

<h3><a name="query-phrase">Wyszukiwanie fraz</a></h3>
<p>
Moesz szuka wyraenia, ktre skada si z dwch lub wicej okrele
otaczajc je podwjnym cudzysowem jak
<code class="operator">"..."</code> lub klamrami jak <code class="operator">{...}</code>.
Precyzja Namazu  w wyszukiwaniu fraz nie jest 100%,
lecz bdne wyniki trafiaj si bardzo rzadko, np.:
</p>

<p class="example">
{GNU Emacs}
</p>

<!-- foo
<p>
You must choose the latter with Tkanamzu or namazu.el.
Musisz wybra ten ostatni z  Tkanamzu lub namazu.el. ???
</p>
-->

<h3><a name="query-substring">Wyszukiwanie okrojonych sw</a></h3>
<p>
S trzy typy wyszukiwania okrojonych sw.
</p>

<dl>
<dt>Przedrostkowe dopasowanie
<dd><code class="example">inter*</code> (okrelenia rozpoczynajce si na <code>inter</code>)
<dt>Wewntrzne dopasowanie
<dd><code class="example">*text*</code> (okrelenia zawierajce si wewntrz <code>text</code>)
<dt>Przyrostkowe dopasowanie
<dd><code class="example">*net</code> (okrelenia koczce si na <code>net</code>)
</dl>


<h3><a name="query-regex">Wyraenia regularne (man grep)</a></h3>

<p>
Moesz uywa wyrae regularnych jako wzr do dopasowywania.
Wyraenia regularne musz by otoczone przez ukoniki tak, jak
<code
class="operator">/.../</code>. Namazu wykorzystuje silnik wyrae regularnych
<ahref="http://www.ruby-lang.org/">Ruby</a>. Oglnie jest on kompatybilny z <a
href="http://www.perl.com/">Perl</a> ,
np.:
</p>

<p class="example">
/pro(gram|blem)s?/
</p>


<h3><a name="query-field">Wyszukiwanie po wyspecyfikowanych polach</a></h3>
<p>
Moesz ograniczy przeszukiwanie do okrelonych pl jak
<code>Subject:</code>, <code>From:</code>,
<code>Message-Id:</code>. Jest to zwaszcza dogodne dla dokumentw typu
Mail/News, np.:
</p>

<ul>
<li><code class="example">+subject:Linux</code><br>
(Zwraca wszystkie dokument zawierajce pola <code>Linux</code>
w <code>Subject:</code> )

<li><code class="example">+subject:"GNU Emacs"</code><br>
(Zwraca wszystkie dokumenty zawierajce pola <code>GNU Emacs</code>
w <code>Subject:</code> )

<li><code class="example">+from:foo@bar.jp</code><br>
(Zwraca wszystkie dokument zawierajce pola <code>foo@bar.jp</code>
w <code>From:</code> )


<li><code class="example">+message-id:&lt;199801240555.OAA18737@foo.bar.jp&gt;</code><br>
(Zwraca pewien dokument zawierajcy wyszczeglnione
<code>Message-Id:</code>)
</ul>

<h3><a name="query-notes">Uwagi</a></h3>

<ul>
<li>We wszystkich zapytaniach, Namazu ignoruje wielko znakw alfabetu.

<li>Japanese phrases are forced to be segmented into
morphemes automatically and are handled them as <a
href="#query-phrase">phrase searching</a>. This processing
causes invalid segmentation occasionally.
<br>Po cholere to tumaczyli na angielski? Ja. w kadym bd razie nie bd, bo nie zamierzam posugiwa
si jz. japoskim.

<li>Alphabet, numbers or a part of symbols (duplicated in
ASCII) characters which defined in JIS X 0208 (Japanese
Industrial Standards) are handled as ASCII characters.
<br>Ju mam skone oczy wedug normy przemysowej JIS X 0208.

<li>Namazu radzi sobie z okreleniami zawierajcymi znaki takie jak
<code>TCP/IP</code>, ale to radzenie sobie nie jest kompletne
moesz opisa
<code>TCP and IP</code> zamiast
<code>TCP/IP</code>, ale moe to by powodem zbyt wielu dopasowa (szumu informacyjnego)

<li>Dopasowania okrojonych sw i szukania po wybranych polach zabieraj
wicej czasu, ni inne metody.

<li>Jeeli chcesz uywa <code class="operator">and</code>,
<code class="operator">or</code> lub <code
class="operator">not</code> po prostu jako okrele, moesz
otoczy je odpowiednio podwjnym cudzysowem tak, jak
<code
class="operator">"..."</code> lub klamrami tak, jak <code
class="operator">{...}</code>.

<!-- foo
You must choose the latter with Tkanamzu or namazu.el.
???????????????????????????????????? ho ku jank siu?
ja nie znaju sztoo eto.
-->

</ul>
